"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const defaultGroups = [["^@\\w", "^\\w"], ["^\\.\\./", "^\\./"], ["\\.s?css$"]];
const memberType = (i1, i2) => {
    const compareHasNamespaceMember = Number(!!i1.namespaceMember) - Number(!!i2.namespaceMember);
    if (compareHasNamespaceMember != 0) {
        return compareHasNamespaceMember;
    }
    const compareHasDefaultMember = Number(!!i1.defaultMember) - Number(!!i2.defaultMember);
    if (compareHasDefaultMember != 0) {
        return compareHasDefaultMember;
    }
    const compareHasNamedMembers = Number(i1.namedMembers.length > 0) - Number(i2.namedMembers.length > 0);
    return compareHasNamedMembers;
};
const ImportSortStyleRegex = (styleApi, _file, options) => {
    const groups = options?.groups || defaultGroups;
    const sortByMemberType = options?.sortByMemberType || false;
    const { and, unicode, moduleName, member, name, hasNoMember, isAbsoluteModule, isRelativeModule } = styleApi;
    return [
        { match: and(hasNoMember, isAbsoluteModule) },
        { separator: true },
        { match: and(hasNoMember, isRelativeModule) },
        { separator: true },
        ...groups.flatMap((group) => {
            return [
                ...group.map((regex) => {
                    const regexMatch = (i) => Boolean(new RegExp(regex).exec(i.moduleName));
                    return {
                        match: regexMatch,
                        sort: [...(sortByMemberType ? [memberType] : []), moduleName(unicode), member(unicode)],
                        sortNamedMembers: name(unicode),
                    };
                }),
                { separator: true },
            ];
        }),
    ];
};
exports.default = ImportSortStyleRegex;
